@@ -15,6 +15,7 @@
 #include "libsandbox.h"
 #include "wrappers.h"
 #include "sb_nr.h"
+#include <alloca.h>
 
 #define LOG_VERSION			"1.0"
 #define LOG_STRING			"VERSION " LOG_VERSION "\n"
@@ -25,7 +26,7 @@
 #define LOG_FMT_RPATH			"FORMAT: R - Canonical Path\n"
 #define LOG_FMT_CMDLINE			"FORMAT: C - Command Line\n"
 
-char sandbox_lib[SB_PATH_MAX];
+char sandbox_lib[PATH_MAX];
 
 typedef struct {
 	bool show_access_violation, on, active, testing, verbose, debug;
@@ -42,9 +43,9 @@ typedef struct {
 static sbcontext_t sbcontext;
 
 static char *cached_env_vars[MAX_DYN_PREFIXES];
-static char log_path[SB_PATH_MAX];
-static char debug_log_path[SB_PATH_MAX];
-static char message_path[SB_PATH_MAX];
+static char log_path[PATH_MAX];
+static char debug_log_path[PATH_MAX];
+static char message_path[PATH_MAX];
 bool sandbox_on = true;
 static bool sb_init = false;
 static bool sb_env_init = false;
@@ -177,7 +178,7 @@ static bool write_logfile(const char *logfile, const char *func, const char *pat
 	ret = true;
 
  error:
-	sb_close(logfd);
+	close(logfd);
 
 	return ret;
 }
@@ -228,7 +229,7 @@ static void init_env_entries(char **prefixes, const char *env, const char *prefi
 	size_t offset = 0;
 
 	while (token && strlen(token) > 0) {
-		char buf[SB_PATH_MAX];
+		char buf[PATH_MAX];
 		if (sb_abspathat(AT_FDCWD, token, buf, sizeof(buf))) {
 			size_t prev_offset = offset;
 			offset = strv_append(prefixes, offset, buf);
@@ -445,7 +446,7 @@ static int check_access(sbcontext_t *sbcontext, int sb_nr, const char *func,
 		 * to be here as for each process, the '/proc/self' symlink
 		 * will differ ...
 		 */
-		char proc_self_fd[SB_PATH_MAX];
+		char proc_self_fd[PATH_MAX];
 		if (realpath(sb_get_fd_dir(), proc_self_fd) &&
 		    !strncmp(resolv_path, proc_self_fd, strlen(proc_self_fd)))
 		{
@@ -565,13 +566,13 @@ static int get_pid_fd(pid_t pid, int dirfd)
 	return r;
 }
 
-static void cleanup_free(void *vp)
+static void cleanup_path(char **p)
 {
-	void **vpp = vp;
-	free(*vpp);
+	if (*p)
+		sb_unmap_path(*p);
 }
 
-#define _cleanup_free_ __attribute__((cleanup(cleanup_free)))
+#define _cleanup_path_ __attribute__((cleanup(cleanup_path)))
 
 /* Return values:
  *  0: failure, caller should abort
@@ -584,8 +585,9 @@ static int check_syscall(sbcontext_t *sbcontext, int sb_nr, const char *func,
 	int old_errno = errno;
 	int result;
 	bool access, debug, verbose, set;
-	_cleanup_free_ char *absolute_path = xmalloc(SB_PATH_MAX);
-	_cleanup_free_ char *resolved_path = xmalloc(SB_PATH_MAX);
+	char *absolute_path, *resolved_path;
+	_cleanup_path_ char *abuf = NULL;
+	_cleanup_path_ char *rbuf = NULL;
 
 	int trace_dirfd = -1;
 	if (trace_pid && (file == NULL || file[0] != '/')) {
@@ -604,12 +606,20 @@ static int check_syscall(sbcontext_t *sbcontext, int sb_nr, const char *func,
 	if (is_symlink_func(sb_nr))
 		flags |= AT_SYMLINK_NOFOLLOW;
 
-	if (!sb_abspathat(dirfd, file, absolute_path, SB_PATH_MAX))
+	absolute_path = abuf = sb_map_path();
+	if (!absolute_path)
+		absolute_path = alloca(PATH_MAX);
+
+	if (!sb_abspathat(dirfd, file, absolute_path, PATH_MAX))
 		return 1;
 
 	sb_debug_dyn("absolute_path: %s\n", absolute_path);
 
-	if (!sb_realpathat(dirfd, file, resolved_path, SB_PATH_MAX,
+	resolved_path = rbuf = sb_map_path();
+	if (!resolved_path)
+		resolved_path = alloca(PATH_MAX);
+
+	if (!sb_realpathat(dirfd, file, resolved_path, PATH_MAX,
 				flags, is_create(sb_nr)))
 		return 1;
 
