@@ -66,7 +66,7 @@ enum sandbox_method_t get_sandbox_method(void);
 
 void *get_dlsym(const char *symname, const char *symver);
 
-extern char sandbox_lib[SB_PATH_MAX];
+extern char sandbox_lib[PATH_MAX];
 extern bool sandbox_on;
 
 struct sb_envp_ctx {
@@ -97,6 +97,8 @@ bool sb_realpathat(int dirfd, const char *restrict path, char *buf, size_t bufsi
 /* most linux systems use ENAMETOOLONG, but some (ia64) use ERANGE, as do some BSDs */
 #define errno_is_too_long() (errno == ENAMETOOLONG || errno == ERANGE)
 
+char *sb_map_path(void);
+int sb_unmap_path(char *path);
 size_t malloc_size(void *ptr);
 
 #include "sbutil.h"
