@@ -1,13 +1,5 @@
-static int trace_sysnum(void)
-{
-	return do_peekuser(PT_ORIG_P0);
-}
-
-static long trace_raw_ret(void *vregs)
-{
-	trace_regs *regs = vregs;
-	return regs->r0;
-}
+#define trace_reg_sysnum orig_p0
+#define trace_reg_ret r0
 
 static unsigned long trace_arg(void *vregs, int num)
 {
