@@ -7,7 +7,5 @@
 
 #define WRAPPER_ARGS_PROTO const char *filename, const struct timeval times[2]
 #define WRAPPER_ARGS filename, times
-#ifndef WRAPPER_SAFE
-# define WRAPPER_SAFE() SB_SAFE(filename)
-#endif
+#define WRAPPER_SAFE() SB_SAFE(filename)
 #include "__wrapper_simple.c"
