@@ -15,7 +15,7 @@ char *get_sandbox_confd(char *path)
 	save_errno();
 	char *p;
 	if (is_env_on(ENV_SANDBOX_TESTING) && (p = getenv("__SANDBOX_CONFD_DIR")))
-		strlcpy(path, p, SB_PATH_MAX);
+		strlcpy(path, p, PATH_MAX);
 	else
 		strcpy(path, SANDBOX_CONFD_DIR);
 	restore_errno();
