@@ -17,10 +17,10 @@ void get_sandbox_rc(char *path)
 {
 	save_errno();
 	if (is_env_on(ENV_SANDBOX_TESTING))
-		snprintf(path, SB_PATH_MAX, "%s/%s",
+		snprintf(path, PATH_MAX, "%s/%s",
 			getenv("__SANDBOX_BASHRC_PATH"), BASHRC_NAME);
 	else
-		snprintf(path, SB_PATH_MAX, "%s/%s",
+		snprintf(path, PATH_MAX, "%s/%s",
 			SANDBOX_BASHRC_PATH, BASHRC_NAME);
 	restore_errno();
 }
