@@ -51,8 +51,6 @@ static void read_config(void)
 	}
 }
 
-static const char sb_sonfigure_opts[] = SANDBOX_CONFIGURE_OPTS;
-
 static void show_version(void)
 {
 	printf(
@@ -71,8 +69,6 @@ static void show_version(void)
 # define SB_PERSONALITIES "no"
 #endif
 		" personalities:  " SB_PERSONALITIES "\n"
-		"\nconfigured with these options:\n%s\n",
-		sb_sonfigure_opts
 	);
 	exit(0);
 }
@@ -103,7 +99,6 @@ static struct option const long_opts[] = {
 	{"bash",          no_argument, NULL, 'c'},
 	{"help",          no_argument, NULL, 'h'},
 	{"version",       no_argument, NULL, 'V'},
-	{"run-configure", no_argument, NULL, 0x800},
 	{NULL,            no_argument, NULL, 0x0}
 };
 static const char * const opts_help[] = {
@@ -130,7 +125,6 @@ static const char * const opts_help[] = {
 	"Run command through bash shell",
 	"Print this help and exit",
 	"Print version and exit",
-	"Run local sandbox configure in same way and exit (developer only)",
 	NULL
 };
 
@@ -187,17 +181,6 @@ static void show_usage(int status)
 	exit(status);
 }
 
-static void run_configure(int argc, char *argv[])
-{
-	int i;
-	char *cmd;
-	xasprintf(&cmd, "set -x; ./configure %s", sb_sonfigure_opts);
-	/* This doesn't need to be fast, so keep it simple. */
-	for (i = optind; i < argc; ++i)
-		xasprintf(&cmd, "%s %s", cmd, argv[i]);
-	exit(system(cmd));
-}
-
 void parseargs(int argc, char *argv[])
 {
 	int i;
@@ -211,8 +194,6 @@ void parseargs(int argc, char *argv[])
 			show_version();
 		case 'h':
 			show_usage(0);
-		case 0x800:
-			run_configure(argc, argv);
 		case '?':
 			show_usage(1);
 		}
