@@ -3,5 +3,4 @@
 [ "${at_xfail}" = "yes" ] && exit 77 # see trace-0
 
 adddeny "${PWD}"
-remove-0 -1 f
-test -e sandbox.log
+remove-0 -1,ENOENT f
