@@ -1,8 +1,6 @@
 #!/bin/sh
 # make sure symlinks don't fail
 
-export SANDBOX_LOG=$PWD/sb.log
-
 addwrite $PWD
 
 mkdir reject || exit 1
@@ -11,4 +9,4 @@ adddeny $PWD/reject
 ln -s reject foo || exit 1
 rmdir-0 -1,ENOTDIR foo || exit 1
 [ -e foo ] || exit 1
-! test -e sb.log
+! test -e sandbox.log
