@@ -2,7 +2,5 @@
 # make sure we catch openat with relative path
 [ "${at_xfail}" = "yes" ] && exit 77 # see trace-0
 
-export SANDBOX_LOG=$PWD/sb.log
 adddeny "${PWD}"
-unlink-0 -1 f
-test -e sb.log
+unlink-0 -1,ENOENT f
