@@ -4,7 +4,7 @@
 #define FUNC_STR "\"%s\", %p"
 #define FUNC_IMP file, times
 #define ARG_CNT 2
-#define ARG_USE "<file> <times:=NULL>"
+#define ARG_USE "<file> <times>"
 
 #define process_args() \
 	s = argv[i++]; \
